==> functional-0.0.2.tgz: package/utils.js <==
/* vim:set ts=2 sw=2 sts=2 expandtab */
/*jshint asi: true undef: true es5: true node: true devel: true
         forin: false latedef: false */
/*global define: true */

!(typeof define !== "function" ? function($){ $(require, exports, module); } : define)(function(require, exports, module, undefined) {

'use strict';

exports['='] = exports.is = function is(actual, expected) {
  return actual === expected
}

exports['!='] = exports.isnt = function(actual, expected) {
  return actual !== expected
}

exports['>'] = exports.greater = function greater() {
}

exports['<'] = exports.less = function less() {
}

exports['&'] = exports.and = function and() {

}

exports['|'] = exports.or = function or() {

}

exports.apply = function apply(target, self) {
  return target.apply.call(self, Array.prototype.slice.call(2, arguments))
}

exports.cond = function condition(assumption, valid, invalid) {
  (assumption ? valid : invalid)()
}

exports.string = function string() {
  var count = arguments.length, index = 0, value = ''
  while (index < count) value += String(arguments[index++])
  return value
}

exports.identity = function identity(value) {
  return value
}

exports['+'] = exports.plus = exports.sum = function sum() {
  var count = arguments.length, index = 0, value = 0
  while (index < count) value += arguments[index++]
  return value
}

exports['-'] = exports.minus = exports.subtract = function subtrac() {
  var count = arguments.length, index = 1, value = count ? arguments[0] : 0
  while (index < count) value -= arguments[index++]
  return value
}

exports['*'] = exports.multiply = function multiply() {
  var count = arguments.length, index = 0, value = 1
  while (index < count) value *= arguments[index++]
  return value
}

exports['/'] = exports.devide = function devide() {
  var count = arguments.length, index = 1, value = count ? arguments[0] : 1
  while (index < count) value /= arguments[index++]
  return value
}

function Map() {
  var elements = Array.prototype.slice.call(arguments)
  return function map(key) {
    var index elements.indexOf
  }
}

});

==> functional-0.0.3.tgz: package/utils.js <==
/* vim:set ts=2 sw=2 sts=2 expandtab */
/*jshint asi: true undef: true es5: true node: true devel: true
         forin: false latedef: false */
/*global define: true */

!(typeof define !== "function" ? function($){ $(require, exports, module); } : define)(function(require, exports, module, undefined) {

'use strict';

exports['='] = exports.is = function is(actual, expected) {
  return actual === expected
}

exports['!='] = exports.isnt = function(actual, expected) {
  return actual !== expected
}

exports['>'] = exports.greater = function greater() {
}

exports['<'] = exports.less = function less() {
}

exports['&'] = exports.and = function and() {

}

exports['|'] = exports.or = function or() {

}

exports.apply = function apply(target, self) {
  return target.apply.call(self, Array.prototype.slice.call(2, arguments))
}

exports.cond = function condition(assumption, valid, invalid) {
  (assumption ? valid : invalid)()
}

exports.string = function string() {
  var count = arguments.length, index = 0, value = ''
  while (index < count) value += String(arguments[index++])
  return value
}

exports.identity = function identity(value) {
  return value
}

exports['+'] = exports.plus = exports.sum = function sum() {
  var count = arguments.length, index = 0, value = 0
  while (index < count) value += arguments[index++]
  return value
}

exports['-'] = exports.minus = exports.subtract = function subtrac() {
  var count = arguments.length, index = 1, value = count ? arguments[0] : 0
  while (index < count) value -= arguments[index++]
  return value
}

exports['*'] = exports.multiply = function multiply() {
  var count = arguments.length, index = 0, value = 1
  while (index < count) value *= arguments[index++]
  return value
}

exports['/'] = exports.devide = function devide() {
  var count = arguments.length, index = 1, value = count ? arguments[0] : 1
  while (index < count) value /= arguments[index++]
  return value
}

exports.$ = function $(lambda) {
  return (typeof(lambda) === 'function' ? lambda :
          exports[lambda]).apply(null, Array.prototype.slice.call(arguments, 1))
}

function iterate(lambda, value) {
  return function stream(next, stop) {
    (function recur(value) {
      return false === next(value) || recur(lambda(value))
    })(lambda(value))
  }
}

});
